import { Store, GetterTree, MutationTree, ActionTree } from 'vuex';
declare type MergedFunctionProcessor<T extends () => any> = Parameters<T>[1] extends undefined ? () => ReturnType<T> : (payload: Parameters<T>[1]) => ReturnType<T>;
declare type GettersTransformer<T extends Record<string, any>> = Readonly<{
    [P in keyof T]: ReturnType<T[P]>;
}>;
declare type MutationsTransformer<T extends Record<string, any>> = {
    [P in keyof T]: MergedFunctionProcessor<T[P]>;
};
declare type ActionTransformer<T extends Record<string, any>> = {
    [P in keyof T]: MergedFunctionProcessor<T[P]>;
};
declare type ModuleTransformer<T> = T extends NuxtModules ? {
    [P in keyof T]: MergedStoreType<T[P]>;
} : {};
declare type BlankStore = {
    getters: {};
    mutations: {};
    actions: {};
    modules: {};
};
declare type NuxtStore = {
    state: () => unknown;
    getters: Record<string, any>;
    mutations: Record<string, any>;
    actions: Record<string, any>;
    modules: NuxtModules;
};
declare type NuxtModules = Record<string, NuxtStore>;
declare type NuxtStoreInput<T extends () => any, G, M, A, S extends {
    [key: string]: NuxtStore;
}> = {
    state: T;
    getters?: G;
    mutations?: M;
    actions?: A;
    modules?: S;
};
declare type MergedStoreType<T extends NuxtStore> = ReturnType<T['state']> & GettersTransformer<T['getters']> & MutationsTransformer<T['mutations']> & ActionTransformer<T['actions']> & ModuleTransformer<T['modules']>;
declare type StoreParameter<T extends () => any> = Parameters<T>[1] extends undefined ? [] : [Parameters<T>[1]];
declare type FunctionProcessor<M extends Record<string, () => any>> = <P extends keyof M>(mutation: P, ...args: StoreParameter<M[P]>) => ReturnType<M[P]>;
export declare type StoreType<T extends Required<NuxtStore>> = {
    state: ReturnType<T['state']> & {
        [P in keyof T['modules']]: ReturnType<T['modules'][P]['state']>;
    };
    getters: {
        [P in keyof T['getters']]: ReturnType<T['getters'][P]>;
    };
    commit: FunctionProcessor<T['mutations']>;
    dispatch: FunctionProcessor<T['actions']>;
};
export declare const getStoreType: <T extends () => any, G, M, A, S extends Record<string, NuxtStore>>(store: NuxtStoreInput<T, G, M, A, S>) => StoreType<NuxtStoreInput<T, G, M, A, S> & BlankStore> & Pick<Store<ReturnType<T>>, "app" | "state" | "replaceState" | "subscribe" | "subscribeAction" | "watch" | "registerModule" | "unregisterModule" | "hotUpdate" | "$router">;
export declare const getAccessorType: <T extends () => any, G extends GetterTree<ReturnType<T>, ReturnType<T>>, M extends MutationTree<ReturnType<T>>, A extends ActionTree<ReturnType<T>, ReturnType<T>>, S extends Record<string, NuxtStore>>(store: NuxtStoreInput<T, G, M, A, S>) => MergedStoreType<NuxtStoreInput<T, G, M, A, S> & BlankStore>;
export declare const useAccessor: <T extends () => any, G extends GetterTree<ReturnType<T>, ReturnType<T>>, M extends MutationTree<ReturnType<T>>, A extends ActionTree<ReturnType<T>, ReturnType<T>>, S extends Record<string, NuxtStore>>(store: Store<ReturnType<T>>, input: Required<NuxtStoreInput<T, G, M, A, S>>) => MergedStoreType<NuxtStoreInput<T, G, M, A, S> & BlankStore>;
export declare const getAccessorFromStore: (pattern: any) => (store: Store<any>) => any;
export {};
